Learn R Programming

baseline (version 1.3-8)

PLSRTestClass: Class "PLSRTest"

Description

A class describing a PLSR prediction test. To run the test, the "pls" package must be installed.

Arguments

Slots

ncomp

Integer vector. The number of PLSR components to test.

cvsegments

A list of the segments to use in the cross-validation.

Objects from the Class

Objects can be created by calls of the form new("PLSRTest", ...).

Extends

Class predictionTest, directly.

Methods

signature(object = "PLSRTest"): Run the test

Author

Bjørn-Helge Mevik and Krisitan Hovde Liland.

See Also

The base class predictionTest. The runTest function. The plsr function from the "pls" package.

Examples

Run this code
showClass("PLSRTest")

Run the code above in your browser using DataLab