A class describing the result of a baseline algorithm test
paramA named list with the parameter values that were tested. This includes both the predictor parameters and the baseline algorithm parameters. All combinations of values are tested.
qualMeasA matrix of quality measure values for the different combinations of parameter values. Each row corresponds to one prediction parameter value, and each coloumn to one combination of baseline parameters.
qualMeas.ind.minThe index in qualMeas of the minimum quality measure value
minQualMeasThe minimum quality measure value
param.ind.minA vector of indices into the elemets of param of the parameter values corresponding to the minimum quality measure value
param.minA list of the parameter values corresponding to the minimum quality measure value
qualMeasNameThe name of the quality measure
Objects are typically created by running
runTest on a baselineAlgTest object.
signature(object = "baselineAlgResult"):
Extract the minQualMeas slot
signature(object = "baselineAlgResult"):
Extract the param slot
signature(object = "baselineAlgResult"):
Extract the param.ind.min slot
signature(object = "baselineAlgResult"):
Extract the param.min slot
signature(object = "baselineAlgResult"):
Extract the qualMeas slot
signature(object = "baselineAlgResult"):
Extract the qualMeas.ind.min slot
signature(object = "baselineAlgResult"):
Extract the qualMeasName slot
Bjørn-Helge Mevik and Kristian Hovde Liland
Class baselineAlgTest, function
runTest.
showClass("baselineAlgResult")
Run the code above in your browser using DataLab