Learn R Programming

baseline (version 1.3-8)

baselineAlgTest: Class "baselineAlgTest"

Description

A class that describes a baseline algorithm test. The test is performed with the function runTest.

Arguments

Slots

algorithm

A "baselineAlg" object. The baseline algorithm to test.

param

A named list with parameter values to test. All combinations of parameters are tested.

extraArgs

A named list of extra parameters to the baseline algorithm. These will be held fixed during the testing.

Objects from the Class

Objects can be created by calls of the form new("baselineAlgTest", ...).

Methods

algorithm

signature(object = "baselineAlgTest"): Extract the algorithm slot

extraArgs

signature(object = "baselineAlgTest"): Extract the extraArgs slot ...

funcName

signature(object = "baselineAlgTest"): Extract the funcName slot ...

param

signature(object = "baselineAlgTest"): Extract the param slot

runTest

signature(object = "baselineAlgTest"): Run the test.

Author

Bjørn-Helge Mevik and Kristian Hovde Liland

See Also

Classes baselineAlg, baselineAlgResult. Function runTest.

Examples

Run this code

showClass("baselineAlgTest")

Run the code above in your browser using DataLab