Stores the result of estimating baselines for one or more spectra.
Arguments
Slots
baseline
A matrix with the estimated baselines
corrected
A matrix with the corrected spectra
spectra
A matrix with the original spectra
call
The call to baseline
Objects from the Class
The normal way to create objects is with
the function baseline. Several baseline algorithms are
available. See baseline for details. There is a plot method
for the class; see plot,baseline-method.
Methods
getBaseline
signature(object = "baseline"): Extract
the estimated baselines
getCall
signature(object = "baseline"): Extract the
call to baseline used to create the object
getCorrected
signature(object = "baseline"): Extract
the corrected spectra
getSpectra
signature(object = "baseline"): Extract the
original spectra
Warning
In a future versoion, one of the slots might be
removed from the class definition and calculated on the fly instead,
in order to save space. Therefore, do use the extractor
functions (getSpectra, getBaseline and
getCorrected) instead of accessing the slots directly.