getSpectra: Functions to extract the components of a "baseline" object
Description
The functions extract the baseline, spectra, corrected
or call slot of a baseline object; usually the
result of a call to baseline.
Usage
getSpectra(object)
getCorrected(object)
getBaseline(object)
getCall(object)
Value
getCall returns the baseline call used to create the
object. The other functions return a matrix with the original spectra,
estimated baselines or corrected spectra.
Arguments
object
A baseline object
Warning
In a future versoion, one of the slots might be removed
from the class definition and calculated on the fly instead, in order to
save space. Therefore, do use the extractor functions
(getSpectra, getBaseline and getCorrected) instead of
accessing the slots directly.