Learn R Programming

baseline (version 1.3-8)

predictionResult: Class "predictionResult"

Description

A class containing the result of running a predictionTest.

Arguments

Slots

param

Numeric vector. The regression parameter values tested.

qualMeas

Numeric vector. The quality measure values for each of the values of the param slot

ind.min

The index (into qualMeas) of the minimum quality measure value.

minQualMeas

The minimum quality measure value.

param.min

The value of the parameter value corresponding to the minimum quality measure value.

qualMeasName

The name of the quality measure.

paramName

The name of the regression parameter.

Objects from the Class

The normal way to create objects is by calling the method runTest for any object of subclass of predictionTest.

Methods

ind.min: signature(object = "predictionResult"): Extract the ind.min slot minQualMeas: signature(object = "predictionResult"): Extract the minQualMeas slot param: signature(object = "predictionResult"): Extract the param slot param.min: signature(object = "predictionResult"): Extract the param.min slot paramName: signature(object = "predictionResult"): Extract the paramName slot qualMeas: signature(object = "predictionResult"): Extract the qualMeas slot qualMeasName: signature(object = "predictionResult"): Extract the qualMeasName slot

Author

Bjørn-Helge Mevik and Kristian Hovde Liland

See Also

Function runTest, class predictionTest, subclasses PLSRTest and ridgeRegressionTest.

Examples

Run this code
showClass("predictionResult")

Run the code above in your browser using DataLab