powered by
A class describing a PLSR prediction test. To run the test, the "pls" package must be installed.
ncomp
Integer vector. The number of PLSR components to test.
cvsegments
A list of the segments to use in the cross-validation.
Objects can be created by calls of the form new("PLSRTest", ...).
new("PLSRTest", ...)
Class predictionTest, directly.
predictionTest
signature(object = "PLSRTest"): Run the test
signature(object = "PLSRTest")
Bjørn-Helge Mevik and Krisitan Hovde Liland.
The base class predictionTest. The runTest function. The plsr function from the "pls" package.
runTest
plsr
showClass("PLSRTest")
Run the code above in your browser using DataLab