powered by
A class that describes a baseline algorithm test. The test is performed with the function runTest.
runTest
algorithm
A "baselineAlg" object. The baseline algorithm to test.
"baselineAlg"
param
A named list with parameter values to test. All combinations of parameters are tested.
extraArgs
A named list of extra parameters to the baseline algorithm. These will be held fixed during the testing.
Objects can be created by calls of the form new("baselineAlgTest", ...).
new("baselineAlgTest", ...)
signature(object = "baselineAlgTest"): Extract the algorithm slot
signature(object = "baselineAlgTest")
signature(object = "baselineAlgTest"): Extract the extraArgs slot ...
signature(object = "baselineAlgTest"): Extract the funcName slot ...
funcName
signature(object = "baselineAlgTest"): Extract the param slot
signature(object = "baselineAlgTest"): Run the test.
Bjørn-Helge Mevik and Kristian Hovde Liland
Classes baselineAlg, baselineAlgResult. Function runTest.
baselineAlg
baselineAlgResult
showClass("baselineAlgTest")
Run the code above in your browser using DataLab