- baselineTests
a list of baselineAlgTest objects.
The baseline algorithms and parameter values to test
- X
A matrix. The spectra to use in the test
- y
A vector or matrix. The response(s) to use in the test
- predictionTest
A predictionTest object. The
predictor and parameter values to use in the test
- postproc
A function, used to postprocess the baseline corrected
spectra prior to prediction testing. The function should take a matrix of
spectra as its only argument, and return a matrix of postprocessed spectra
- tmpfile
The basename of the files used to store intermediate
calculations for checkpointing. Defaults to "tmp.baseline"
- verbose
Logical, specifying whether the test should print out
progress information. Default is FALSE
- cleanTmp
Logical, specifying whether the intermediate files should be
deleted when the optimisation has finished. Default is FALSE
- object
An mvr object, as returned by pls::plsr. Internal
helper used by doOptim; not meant to be called directly.
- estimate
Character vector of estimate types, passed on from pls::MSEP.
- newdata
Optional new data used to calculate the validation statistics.
- ncomp
Vector of the number of components to calculate statistics for.
- comps
Alternative to ncomp, a vector of specific components to use.
- intercept
Logical, whether statistics for the intercept-only model should be included.
- se
Logical, whether to calculate standard errors.
- ...
Other arguments, currently unused by mvrValstats.