Takes the result of an optimisation (a call to doOptim)
and extracts the minimum quality measure value along with the
parameters giving rise to the value.
overall.min(results)Result of call to doOptim
A list with components
The minimum quality measure value
The name of the baseline algorithm corresponding to the minimum
A list with the parameter values corresponding to the minimum quality measure value