A class containing the result of running a
predictionTest.
paramNumeric vector. The regression parameter values tested.
qualMeasNumeric vector. The quality measure values for each of the values of the param slot
ind.minThe index (into qualMeas) of the minimum quality measure value.
minQualMeasThe minimum quality measure value.
param.minThe value of the parameter value corresponding to the minimum quality measure value.
qualMeasNameThe name of the quality measure.
paramNameThe name of the regression parameter.
The normal way to create objects is by calling the method
runTest for any object of subclass of
predictionTest.
ind.min: signature(object = "predictionResult"): Extract the ind.min slot
minQualMeas: signature(object = "predictionResult"): Extract the minQualMeas slot
param: signature(object = "predictionResult"): Extract the param slot
param.min: signature(object = "predictionResult"): Extract the param.min slot
paramName: signature(object = "predictionResult"): Extract the paramName slot
qualMeas: signature(object = "predictionResult"): Extract the qualMeas slot
qualMeasName: signature(object = "predictionResult"): Extract the qualMeasName slot
Bjørn-Helge Mevik and Kristian Hovde Liland
Function runTest, class predictionTest, subclasses PLSRTest and ridgeRegressionTest.